u n i t o . i t - l'Università di Torino on line - MyUniTo

u n i t o . i t - l'Università di Torino on line

# UNITO.it

[Vai al contenuto] [Vai alla Home Page]

## Scegli la visualizzazione

- Grafica
- Naviga senza grafica

## Strumenti di ricerca

Chiave di ricerca:
Ricerca avanzata Rubrica Cerca per struttura Mappa Strutture

#### Ricordami la password

Inserire la propria username e l'indirizzo e-mail personale.
Una volta verificata la presenza negli archivi dell'Ateneo delle credenziali e dell'indirizzo e-mail, il sistema invierà una mail all'indirizzo personale indicato che contiene le istruzioni operative successive per procedere al recupero della password di accesso al Portale e ai servizi on line.
ATTENZIONE: non utilizzare l'indirizzo e-mail istituzionale, del tipo nome.cognome@unito.it per il personale docente e tecnico amministrativo e nome.cognome@studenti.unito.it o matricola@studenti.unito.it per gli studenti, ma l'indirizzo e-mail personale - per gli studenti l'indirizzo e-mail utilizzato per la registrazione al Portale oppure quello modificato dopo l'iscrizione all'Università tramite la segreteria studenti o direttamente dal Portale di Ateneo - per il personale (docente e tecnico-amministrativo) l'indirizzo e-mail presente, se modificato, nella rubrica dei dati personali dell'Ateneo (per modificarlo, fare login sul Portale, Servizi on line, Modifica dati in rubrica).

Username: |  |
Email: |  |
Digita i caratteri visualizzati nell'immagine sottostante:

- Riferimenti, contatti, PEC, reclami e segnalazioni
- Note legali
- Privacy
- Accessibilità
- In collaborazione con Cineca

Università degli Studi di Torino - Via Verdi, 8 - 10124 Torino - Centralino +39 011 6706111
P.I. 02099550010 - C.F. 80088230018 - IBAN IT07N0306909217100000046985
[Torna all'inizio del contenuto] [Torna al menu di navigazione]